/*
  license GPL v3 ...........

  description of this file:
  a page for viewing a user selected RSS feed ;

*/

import QtQuick 2.0
import QtQuick.XmlListModel 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1
import "./dateutils.js" as DateUtils
import "databasemodule_v2.js" as DB

Page {
    objectName: "rssfeedpage"
    id: pageRoot

    property alias articleView: innerArticleView

    function setFeed(model, index) {
        innerArticleView.setFeed(model, index)
    }

    ArticleViewItem {
        id: innerArticleView

        anchors.fill: parent
    }

    tools: ToolbarItems {
        objectName: "pageBackBtn"
        id: toolbar

        ToolbarButton {
            id: readingOptionsButton

            visible: true
            action: Action {
                text:  i18n.tr("Options")
                iconSource: Qt.resolvedUrl("./icons_tmp/settings.svg")
                onTriggered: {
                    PopupUtils.open(readingOptionsPopoverComponent, readingOptionsButton)
                }
            }
        }

        ToolbarButton {
            action: Action {
                text:  innerArticleView.rssItem == null ? "" : (innerArticleView.rssItem.favourite == "0" ? i18n.tr("Save") : i18n.tr("Remove"))
                iconSource: {
                    if (innerArticleView.rssItem == null || innerArticleView.rssItem.favourite == "0")
                        return Qt.resolvedUrl("./icons_tmp/favorite-unselected.svg")
                    else return Qt.resolvedUrl("./icons_tmp/favorite-selected.svg")
                }
                onTriggered: {
                    var fav = (innerArticleView.rssItem.favourite == "0" ? "1" : "0")
                    var dbResult = DB.updateArticleFavourite(innerArticleView.rssItem.id, fav)
                    if (dbResult.rowsAffected === 1) {
                        innerArticleView.articleFavouriteChanged(innerArticleView.rssItem, fav)
                    }
                }
            }
        }

        ToolbarButton {
            action: Action {
                text:  i18n.tr("Open site")
                iconSource: Qt.resolvedUrl("./icons_tmp/go-to.svg")
                onTriggered: {
                    Qt.openUrlExternally(innerArticleView.rssItem.link)
                }
            }
        }
    }

    Component {
        id: readingOptionsPopoverComponent

        ReadingOptions { }
    } // Comp

}


